@@ -2,7 +2,7 @@
  * Like what you see? Join us!
  * https://www.univention.com/about-us/careers/vacancies/
  *
- * Copyright 2011-2023 Univention GmbH
+ * Copyright 2011-2024 Univention GmbH
  *
  * https://www.univention.de/
  *
@@ -189,6 +189,9 @@ define([
 		// reference to the last item in the navigation on which a context menu has been opened
 		_navContextItem: null,
 
+		// base of the ldap objects
+		_ldapBase: '',
+
 		// a dict of variable -> value entries for relevant UCR variables
 		_ucr: null,
 
@@ -242,7 +245,10 @@ define([
 				deferred.resolve(ucr);
 				return deferred;
 			}
-			return tools.ucr(['directory/manager/web*', 'ldap/base', 'ad/member']).then(lang.hitch(this, function(ucr) {
+			return tools.ucr(['directory/manager/web*', 'ldap/base', 'ad/member', 'directory/manager/blocklist/enabled']).then(lang.hitch(this, function(ucr) {
+				if (! this._ldapBase) {
+					this._ldapBase = ucr['ldap/base'];
+				}
 				this._ucr = lang.setObject('umc.modules.udm.ucr', ucr);
 			}));
 		},
@@ -319,6 +325,7 @@ define([
 					metaInfo: moduleCache.getMetaInfo(),
 					ucr: this._loadUCRVariables()
 				}).then(lang.hitch(this, function(results) {
+					this._ldapBase = results.metaInfo.ldap_base;
 					this._reports = results.reports;
 					this._default_columns = results.columns;
 					this.renderSearchPage(results.containers, results.metaInfo);
@@ -398,7 +405,7 @@ define([
 
 		_ldapDN2TreePath: function(ldapDN) {
 			var path = [];
-			while (ldapDN != this._ucr[ 'ldap/base' ]) {
+			while (ldapDN != this._ldapBase) {
 				path.unshift(ldapDN);
 				ldapDN = ldapDN.slice(ldapDN.indexOf(',') + 1);
 			}
@@ -406,6 +413,19 @@ define([
 
 			return path;
 		},
+		_checkModuleUCRDisabled: function() {
+		        var ucrVar = {
+				'blocklists/all'   : 'directory/manager/blocklist/enabled'
+			}[this.moduleFlavor];
+			var enabled = tools.isTrue(this._ucr[ucrVar]);
+			var warningText = {
+				'blocklists/all'   : _('Blocklists are not enabled. To enable this functionality, set the UCR variable "%s" to "true" on each Domain Controller in the domain.', ucrVar)
+			}[this.moduleFlavor];
+
+			if (warningText && !enabled) {
+				this.addWarning(warningText);
+			}
+		},
 
 		_checkMissingApp: function() {
 			var _warningText = lang.hitch(this, function(app, link) {
@@ -560,6 +580,7 @@ define([
 			this.addChild(this._searchPage);
 			this._checkMissingApp();
 			this._loadUCRVariables().then(lang.hitch(this, '_preloadDetailPage'));
+			this._checkModuleUCRDisabled();
 			if (this.moduleFlavor === 'users/user') {
 				_loadGridViewPreference().then(lang.hitch(this, function(view) {
 					this._setGridView(view);
@@ -810,7 +831,7 @@ define([
 				});
 			}
 
-			// the navigation needs a slightly modified store that uses the UMCP query
+			// the navigation needs a slightly modified store that uses the UMC query
 			// function 'udm/nav/object/query'
 			var _store = this.moduleStore;
 			if ('navigation' == this.moduleFlavor) {
@@ -1536,7 +1557,7 @@ define([
 					});
 				}, this);
 
-				// send UMCP command to move the objects
+				// send UMC command to move the objects
 				this._progressBar.reset();
 				var moveOperation = this.umcpProgressCommand(this._progressBar, 'udm/move', params).then(
 					lang.hitch(this, function(result) {
@@ -2006,7 +2027,7 @@ define([
 				moduleFlavor: this.moduleFlavor,
 				objectType: objectType,
 				operation: operation,
-				ldapBase: this._ucr['ldap/base'],
+				ldapBase: this._ldapBase,
 				ldapName: ldapName,
 				newObjectOptions: newObjOptions,
 				moduleWidget: this,
