@@ -7,7 +7,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2011-2023 Univention GmbH
+# Copyright 2011-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -39,6 +39,7 @@ import functools
 import gc
 import inspect
 import locale
+import operator
 import re
 import sys
 import threading
@@ -183,7 +184,7 @@ class AppAttributes(object):
     @classmethod
     def attributes_for_module(cls, module):
         ret = []
-        for _option_name, option_def in cls.data_for_module(module).items():
+        for option_def in cls.data_for_module(module).values():
             ret.extend(option_def['attributes'])
         return ret
 
@@ -404,14 +405,14 @@ class UDM_Module(object):
         if force_reload:
             AppAttributes._cache = None
 
-    def get_ldap_connection(self):
+    def get_ldap_connection(self, base=None):
         if get_bind_function():
             try:
-                self.ldap_connection, po = get_user_connection(bind=get_bind_function(), write=True)
+                self.ldap_connection, _po = get_user_connection(bind=get_bind_function(), write=True)
             except (LDAPError, udm_errors.ldapError):
-                self.ldap_connection, po = get_user_connection(bind=get_bind_function(), write=True)
+                self.ldap_connection, _po = get_user_connection(bind=get_bind_function(), write=True)
             self.ldap_position = udm.uldap.position(self.ldap_connection.base)
-        return self.ldap_connection, udm.uldap.position(self.ldap_connection.base)
+        return self.ldap_connection, udm.uldap.position(base if base else self.ldap_connection.base)
 
     def load(self, module=None, template_object=None, force_reload=False):
         """
@@ -514,7 +515,7 @@ class UDM_Module(object):
 
     def create(self, ldap_object, container=None, superordinate=None):
         """Creates a LDAP object"""
-        ldap_connection, ldap_position = self.get_ldap_connection()
+        ldap_connection, ldap_position = self.get_ldap_connection(base=self.module.object.ldap_base)
         if superordinate == 'None':
             superordinate = None
         if container:
@@ -558,7 +559,7 @@ class UDM_Module(object):
                 obj.options = options
                 del ldap_object['$options$']
             if '$policies$' in ldap_object:
-                obj.policies = reduce(lambda x, y: x + y, ldap_object['$policies$'].values(), [])
+                obj.policies = reduce(operator.add, ldap_object['$policies$'].values(), [])
                 del ldap_object['$policies$']
 
             self._map_properties(obj, ldap_object)
@@ -637,7 +638,7 @@ class UDM_Module(object):
                 del ldap_object['$options$']
             MODULE.info('Modifying LDAP object %s' % obj.dn)
             if '$policies$' in ldap_object:
-                obj.policies = reduce(lambda x, y: x + y, ldap_object['$policies$'].values(), [])
+                obj.policies = reduce(operator.add, ldap_object['$policies$'].values(), [])
                 del ldap_object['$policies$']
 
             self._map_properties(obj, ldap_object)
@@ -706,7 +707,7 @@ class UDM_Module(object):
 
     def get(self, ldap_dn=None, superordinate=None, attributes=[]):
         """Retrieves details for a given LDAP object"""
-        ldap_connection, ldap_position = self.get_ldap_connection()
+        ldap_connection, _ldap_position = self.get_ldap_connection()
         try:
             if ldap_dn is not None:
                 if superordinate is None:
@@ -767,6 +768,13 @@ class UDM_Module(object):
         """Descriptive name of the UDM module"""
         return getattr(self.module, 'short_description', getattr(self.module, 'module', ''))
 
+    @property
+    def ldap_base(self):
+        """Default LDAP base of the UDM module"""
+        if hasattr(self.module, 'object'):
+            return getattr(self.module.object, 'ldap_base', ucr.get('ldap/base'))
+        return ucr.get('ldap/base')
+
     @property
     def description(self):
         """Descriptive text of the UDM module"""
@@ -851,8 +859,6 @@ class UDM_Module(object):
             description = self.property_description(obj, description_property_name)
         if not description:
             description = udm_objects.description(obj)
-        if description and description.isdigit():
-            description = int(description)
         return description
 
     def property_description(self, obj, key):
@@ -873,7 +879,7 @@ class UDM_Module(object):
 
     def get_layout(self, ldap_dn=None):
         """Layout information"""
-        ldap_connection, ldap_position = self.get_ldap_connection()
+        ldap_connection, _ldap_position = self.get_ldap_connection()
         layout = getattr(self.module, 'layout', [])
         if ldap_dn is not None:
             mod = get_module(None, ldap_dn, ldap_connection)
@@ -988,7 +994,7 @@ class UDM_Module(object):
                 # E.g. users/user mailHomeServer; see Bug #33329, Bug #42903
 
                 try:
-                    item['default'] = [x['id'] for x in read_syntax_choices(_get_syntax(prop.syntax.name), ldap_connection=ldap_connection, ldap_position=ldap_position) if x['id']][0]
+                    item['default'] = [x['id'] for x in read_syntax_choices(_get_syntax(prop.syntax.name), ldap_connection=ldap_connection, ldap_position=ldap_position) if x['id']][0]  # noqa: RUF015
                 except IndexError:
                     pass
 
@@ -1045,17 +1051,17 @@ class UDM_Module(object):
         return getattr(self.module, 'template', None)
 
     def get_default_container(self):
-        ldap_connection, ldap_position = self.get_ldap_connection()
+        _ldap_connection, ldap_position = self.get_ldap_connection()
         # TODO: move code below into UDM!
         if hasattr(self.module, 'policy_position_dn_prefix'):
             return '%s,cn=policies,%s' % (self.module.policy_position_dn_prefix, ldap_position.getBase())
 
         defaults = self.get_default_containers()
-        return defaults[0] if defaults else ldap_position.getBase()
+        return defaults[0] if defaults else self.module.object.ldap_base
 
     def get_default_containers(self):
         """List of LDAP DNs of default containers"""
-        ldap_connection, ldap_position = self.get_ldap_connection()
+        ldap_connection, _ldap_position = self.get_ldap_connection()
         return self.module.object.get_default_containers(ldap_connection)
 
     @property
@@ -1083,7 +1089,7 @@ class UDM_Module(object):
         return policies
 
     def get_policy_references(self, dn):
-        ldap_connection, ldap_position = self.get_ldap_connection()
+        ldap_connection, _ldap_position = self.get_ldap_connection()
         references = []
         if self.is_policy_module():  # TODO: move into the handlers/policies/*.py
             search_filter = filter_format("(&(objectClass=univentionPolicyReference)(univentionPolicyReference=%s))", (dn,))
@@ -1128,7 +1134,7 @@ class UDM_Module(object):
         if self.name.startswith('dns/'):
             return 'dns/dns'
         ldap_connection, ldap_position = self.get_ldap_connection()
-        base, name = split_module_name(self.name)
+        base, _name = split_module_name(self.name)
         for module in [x for x in udm_modules.modules.keys() if x.startswith(base)]:
             mod = UDM_Module(module, ldap_connection=ldap_connection, ldap_position=ldap_position)
             children = getattr(mod.module, 'childmodules', [])
@@ -1186,13 +1192,13 @@ def split_module_name(module_name):
     return (None, None)
 
 
-def ldap_dn2path(ldap_dn, include_rdn=True):
+def ldap_dn2path(ldap_dn, include_rdn=True, ldap_base=None):
     """
     Returns a path representation of an LDAP DN. If include_rdn is
     false just the container of the given object is returned in a path
     representation
     """
-    ldap_base = ucr.get('ldap/base')
+    ldap_base = ldap_base or ucr.get('ldap/base')
     if not ldap_base or not ldap_dn.lower().endswith(ldap_base.lower()):
         return ldap_dn
     rel_path = ldap_dn[:-(1 + len(ldap_base))]
@@ -1217,7 +1223,7 @@ def _get_module(flavor, ldap_dn, attributes=None, ldap_connection=None, ldap_pos
     if flavor is None or flavor == 'navigation':
         base = None
     else:
-        base, name = split_module_name(flavor)
+        base, _name = split_module_name(flavor)
     modules = udm_modules.objectType(None, ldap_connection, ldap_dn, attributes, module_base=base)
 
     if not modules:
